powered by
Displays a formatted summary of a draws description using cli formatting.
# S3 method for describe_draws print(x, ...)
Invisibly returns x (for pipe chaining).
x
A describe_draws object from describe_draws().
describe_draws
describe_draws()
Additional arguments (currently unused).
if (FALSE) { # After creating draws_obj via the rbmi pipeline (see describe_draws): desc <- describe_draws(draws_obj) print(desc) # Formatted cli output with method, formula, samples, convergence }
Run the code above in your browser using DataLab